@@ -51,6 +51,7 @@ class CreateBookInput(MutationSchema):
     title: str
     author: str
     price: Decimal
+    location_ids: list[int] = []
     is_backorder: bool = True
     product_type: str = "Textbook"
     subtitle: t.Optional[str] = None
@@ -87,6 +88,9 @@ class CreateBookInput(MutationSchema):
                     "sku": self.isbn,
                     "barcode": self.isbn,
                     "price": str(self.price),
+                    "inventoryItem": {
+                        "tracked": True,
+                    },
                 }
             ],
             "productCategory": {
@@ -122,6 +126,15 @@ class CreateBookInput(MutationSchema):
         }
         if self.cover_image:
             data["images"] = [{"altText": self.title, "src": self.cover_image}]
+        if self.location_ids:
+            data["variants"][0]["inventoryPolicy"] = "CONTINUE"
+            data["variants"][0]["inventoryQuantities"] = [
+                {
+                    "locationId": f"gid://shopify/Location/{location_id}",
+                    "availableQuantity": 100,
+                }
+                for location_id in self.location_ids
+            ]
         return data
 
 
